==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Arc/ArcCPA/ts/ArcCPA_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>ArcCPA</name>
    <message>
        <location filename="../ArcCPA.js" line="+66"/>
        <source>Center</source>
        <translation>中心</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Point on arc or radius</source>
        <translation>弧或半径上的点</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Point on arc</source>
        <translation>弧上的点</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Start angle</source>
        <translation>起始角度</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>End angle</source>
        <translation>结束角度</translation>
    </message>
    <message>
        <location filename="../ArcCPA.ui" line="+17"/>
        <source>Direction:</source>
        <translation>方向：</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Counter Clockwise (positive)</source>
        <translation>逆时针（正向）</translation>
    </message>
    <message>
        <location line="+13"/>
        <location line="+17"/>
        <source>Direction</source>
        <translation>方向</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Clockwise (Negative)</source>
        <translation>顺时针（反向）</translation>
    </message>
    <message>
        <location filename="../ArcCPAInit.js" line="+2"/>
        <source>&amp;Center, Point, Angles</source>
        <translation>中心、点、角度(&amp;C)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc from center, point on arc and angles</source>
        <translation>按中心、弧上的点和角度画弧</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Arc/ArcCPA/ts/ArcCPA_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>ArcCPA</name>
    <message>
        <location filename="../ArcCPA.js" line="+66"/>
        <source>Center</source>
        <translation>中心</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Point on arc or radius</source>
        <translation>弧或半径上的点</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Point on arc</source>
        <translation>弧上的点</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Start angle</source>
        <translation>起始角度</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>End angle</source>
        <translation>结束角度</translation>
    </message>
    <message>
        <location filename="../ArcCPA.ui" line="+17"/>
        <source>Direction:</source>
        <translation>方向：</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Counter Clockwise (positive)</source>
        <translation>逆时针（正向）</translation>
    </message>
    <message>
        <location line="+13"/>
        <location line="+17"/>
        <source>Direction</source>
        <translation>方向</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Clockwise (Negative)</source>
        <translation>顺时针（反向）</translation>
    </message>
    <message>
        <location filename="../ArcCPAInit.js" line="+2"/>
        <source>&amp;Center, Point, Angles</source>
        <translation>中心、点、角度(&amp;C)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc from center, point on arc and angles</source>
        <translation>以中心、弧上的点和角度画弧</translation>
    </message>
</context>
</TS>
